Change in osmo-bts[master]: tx_power: Take into account max-initial when ramping up bigger power ...

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

pespin gerrit-no-reply at lists.osmocom.org
Mon Jul 27 15:42:01 UTC 2020


pespin has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-bts/+/19408 )


Change subject: tx_power: Take into account max-initial when ramping up bigger power lvl intervals
......................................................................

tx_power: Take into account max-initial when ramping up bigger power lvl intervals

Until now, power-ramp max-initial was only taken into account in order
to skip ramping if the desired target level was below it, in order to
forbid growin too quickly or applying directly to much power given power
amplifier requirements.
However, in the event that a higher tx power level is desired,
max-initial was not taking into account and ramping simply started from
current tx power level, which could be a lot lower than max-initial.
Allow shortcutting the ramping in that case so that max-initial is
applied directly, and ramping continues from there, in order to have a
more expected behavior (max-initial applied the same).

Since max-initial can since a few commits before handle a negative
value, this means One can for instance set max-initial to -10 and still
keep the old behavior of ramping step by step from -10 (rf-locked in
osmo-bts-trx) to 0 or 7 or whatever is the nominal power
(max_power_red).

Change-Id: I4e5742ecdbf66d77ff9445999f6fff43bbf4856a
---
M src/common/tx_power.c
1 file changed, 3 insertions(+), 1 deletion(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-bts refs/changes/08/19408/1

diff --git a/src/common/tx_power.c b/src/common/tx_power.c
index 7f134ca..c5ea7ed 100644
--- a/src/common/tx_power.c
+++ b/src/common/tx_power.c
@@ -276,8 +276,10 @@
 			tpp->ramp.attenuation_mdB = 0;
 			power_ramp_timer_cb(trx);
 		} else {
 			/* We need to step it up. Start from the current value */
 			/* Set attenuation to cause no power change right now */
+			if (tpp->p_total_cur_mdBm + tpp->ramp.step_size_mdB < tpp->ramp.max_initial_pout_mdBm)
+				tpp->p_total_cur_mdBm = tpp->ramp.max_initial_pout_mdBm - tpp->ramp.step_size_mdB;
 			tpp->ramp.attenuation_mdB = tpp->p_total_tgt_mdBm - tpp->p_total_cur_mdBm;
 
 			/* start with the first step */
@@ -276,8 +276,10 @@
 			power_ramp_timer_cb(trx);
 		} else {
-			/* We need to step it up. Start from the current value */
+			/* We need to step it up. Start from the current value, shortcutting to max-initial. */
 			/* Set attenuation to cause no power change right now */

-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/19408
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I4e5742ecdbf66d77ff9445999f6fff43bbf4856a
Gerrit-Change-Number: 19408
Gerrit-PatchSet: 1
Gerrit-Owner: pespin <pespin at sysmocom.de>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20200727/8ea2151a/attachment.htm>


More information about the gerrit-log mailing list